# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/auth/v1beta1/auth.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/auth/v1beta1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/auth/v1beta1/auth.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xa1\x02\n\x0b\x42\x61seAccount\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12V\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\'\xea\xde\x1f\x14public_key,omitempty\xa2\xe7\xb0*\npublic_keyR\x06pubKey\x12%\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04R\raccountNumber\x12\x1a\n\x08sequence\x18\x04 \x01(\x04R\x08sequence:C\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1c\x63osmos.auth.v1beta1.AccountI\x8a\xe7\xb0*\x16\x63osmos-sdk/BaseAccount\"\xec\x01\n\rModuleAccount\x12I\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01R\x0b\x62\x61seAccount\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0bpermissions\x18\x03 \x03(\tR\x0bpermissions:Z\x88\xa0\x1f\x00\xca\xb4-\"cosmos.auth.v1beta1.ModuleAccountI\x8a\xe7\xb0*\x18\x63osmos-sdk/ModuleAccount\x92\xe7\xb0*\x0emodule_account\"\x84\x01\n\x10ModuleCredential\x12\x1f\n\x0bmodule_name\x18\x01 \x01(\tR\nmoduleName\x12\'\n\x0f\x64\x65rivation_keys\x18\x02 \x03(\x0cR\x0e\x64\x65rivationKeys:&\x8a\xe7\xb0*!cosmos-sdk/GroupAccountCredential\"\xd7\x02\n\x06Params\x12.\n\x13max_memo_characters\x18\x01 \x01(\x04R\x11maxMemoCharacters\x12 \n\x0ctx_sig_limit\x18\x02 \x01(\x04R\ntxSigLimit\x12\x30\n\x15tx_size_cost_per_byte\x18\x03 \x01(\x04R\x11txSizeCostPerByte\x12O\n\x17sig_verify_cost_ed25519\x18\x04 \x01(\x04\x42\x18\xe2\xde\x1f\x14SigVerifyCostED25519R\x14sigVerifyCostEd25519\x12U\n\x19sig_verify_cost_secp256k1\x18\x05 \x01(\x04\x42\x1a\xe2\xde\x1f\x16SigVerifyCostSecp256k1R\x16sigVerifyCostSecp256k1:!\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x18\x63osmos-sdk/x/auth/ParamsB\xbd\x01\n\x17\x63om.cosmos.auth.v1beta1B\tAuthProtoP\x01Z)github.com/cosmos/cosmos-sdk/x/auth/types\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43osmos.Auth.V1beta1\xca\x02\x13\x43osmos\\Auth\\V1beta1\xe2\x02\x1f\x43osmos\\Auth\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Auth::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.auth.v1beta1B\tAuthProtoP\001Z)github.com/cosmos/cosmos-sdk/x/auth/types\242\002\003CAX\252\002\023Cosmos.Auth.V1beta1\312\002\023Cosmos\\Auth\\V1beta1\342\002\037Cosmos\\Auth\\V1beta1\\GPBMetadata\352\002\025Cosmos::Auth::V1beta1'
  _globals['_BASEACCOUNT'].fields_by_name['address']._loaded_options = None
  _globals['_BASEACCOUNT'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_BASEACCOUNT'].fields_by_name['pub_key']._loaded_options = None
  _globals['_BASEACCOUNT'].fields_by_name['pub_key']._serialized_options = b'\352\336\037\024public_key,omitempty\242\347\260*\npublic_key'
  _globals['_BASEACCOUNT']._loaded_options = None
  _globals['_BASEACCOUNT']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\034cosmos.auth.v1beta1.AccountI\212\347\260*\026cosmos-sdk/BaseAccount'
  _globals['_MODULEACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_MODULEACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _globals['_MODULEACCOUNT']._loaded_options = None
  _globals['_MODULEACCOUNT']._serialized_options = b'\210\240\037\000\312\264-\"cosmos.auth.v1beta1.ModuleAccountI\212\347\260*\030cosmos-sdk/ModuleAccount\222\347\260*\016module_account'
  _globals['_MODULECREDENTIAL']._loaded_options = None
  _globals['_MODULECREDENTIAL']._serialized_options = b'\212\347\260*!cosmos-sdk/GroupAccountCredential'
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_ed25519']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_ed25519']._serialized_options = b'\342\336\037\024SigVerifyCostED25519'
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_secp256k1']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_secp256k1']._serialized_options = b'\342\336\037\026SigVerifyCostSecp256k1'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\030cosmos-sdk/x/auth/Params'
  _globals['_BASEACCOUNT']._serialized_start=151
  _globals['_BASEACCOUNT']._serialized_end=440
  _globals['_MODULEACCOUNT']._serialized_start=443
  _globals['_MODULEACCOUNT']._serialized_end=679
  _globals['_MODULECREDENTIAL']._serialized_start=682
  _globals['_MODULECREDENTIAL']._serialized_end=814
  _globals['_PARAMS']._serialized_start=817
  _globals['_PARAMS']._serialized_end=1160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/crypto/proof.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'tendermint/crypto/proof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/crypto/proof.proto\x12\x11tendermint.crypto\x1a\x14gogoproto/gogo.proto\"f\n\x05Proof\x12\x14\n\x05total\x18\x01 \x01(\x03R\x05total\x12\x14\n\x05index\x18\x02 \x01(\x03R\x05index\x12\x1b\n\tleaf_hash\x18\x03 \x01(\x0cR\x08leafHash\x12\x14\n\x05\x61unts\x18\x04 \x03(\x0cR\x05\x61unts\"K\n\x07ValueOp\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12.\n\x05proof\x18\x02 \x01(\x0b\x32\x18.tendermint.crypto.ProofR\x05proof\"J\n\x08\x44ominoOp\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x16\n\x06output\x18\x03 \x01(\tR\x06output\"C\n\x07ProofOp\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\">\n\x08ProofOps\x12\x32\n\x03ops\x18\x01 \x03(\x0b\x32\x1a.tendermint.crypto.ProofOpB\x04\xc8\xde\x1f\x00R\x03opsB\xbe\x01\n\x15\x63om.tendermint.cryptoB\nProofProtoP\x01Z4github.com/cometbft/cometbft/proto/tendermint/crypto\xa2\x02\x03TCX\xaa\x02\x11Tendermint.Crypto\xca\x02\x11Tendermint\\Crypto\xe2\x02\x1dTendermint\\Crypto\\GPBMetadata\xea\x02\x12Tendermint::Cryptob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.crypto.proof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.tendermint.cryptoB\nProofProtoP\001Z4github.com/cometbft/cometbft/proto/tendermint/crypto\242\002\003TCX\252\002\021Tendermint.Crypto\312\002\021Tendermint\\Crypto\342\002\035Tendermint\\Crypto\\GPBMetadata\352\002\022Tendermint::Crypto'
  _globals['_PROOFOPS'].fields_by_name['ops']._loaded_options = None
  _globals['_PROOFOPS'].fields_by_name['ops']._serialized_options = b'\310\336\037\000'
  _globals['_PROOF']._serialized_start=74
  _globals['_PROOF']._serialized_end=176
  _globals['_VALUEOP']._serialized_start=178
  _globals['_VALUEOP']._serialized_end=253
  _globals['_DOMINOOP']._serialized_start=255
  _globals['_DOMINOOP']._serialized_end=329
  _globals['_PROOFOP']._serialized_start=331
  _globals['_PROOFOP']._serialized_end=398
  _globals['_PROOFOPS']._serialized_start=400
  _globals['_PROOFOPS']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/feegrant/v1beta1/genesis.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/feegrant/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/feegrant/v1beta1/genesis.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a\x11\x61mino/amino.proto\"Y\n\x0cGenesisState\x12I\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.GrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\nallowancesB\xc2\x01\n\x1b\x63om.cosmos.feegrant.v1beta1B\x0cGenesisProtoP\x01Z\x17\x63osmossdk.io/x/feegrant\xa2\x02\x03\x43\x46X\xaa\x02\x17\x43osmos.Feegrant.V1beta1\xca\x02\x17\x43osmos\\Feegrant\\V1beta1\xe2\x02#Cosmos\\Feegrant\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Feegrant::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.feegrant.v1beta1B\014GenesisProtoP\001Z\027cosmossdk.io/x/feegrant\242\002\003CFX\252\002\027Cosmos.Feegrant.V1beta1\312\002\027Cosmos\\Feegrant\\V1beta1\342\002#Cosmos\\Feegrant\\V1beta1\\GPBMetadata\352\002\031Cosmos::Feegrant::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['allowances']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['allowances']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=147
  _globals['_GENESISSTATE']._serialized_end=236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/upgrade/v1beta1/upgrade.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/upgrade/v1beta1/upgrade.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/upgrade/v1beta1/upgrade.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xef\x01\n\x04Plan\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\x18\x01\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x04time\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12L\n\x15upgraded_client_state\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01R\x13upgradedClientState:\x18\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x0f\x63osmos-sdk/Plan\"\xdb\x01\n\x17SoftwareUpgradeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12;\n\x04plan\x18\x03 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x04plan:K\x18\x01\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\"cosmos-sdk/SoftwareUpgradeProposal\"\xaa\x01\n\x1d\x43\x61ncelSoftwareUpgradeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription:Q\x18\x01\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*(cosmos-sdk/CancelSoftwareUpgradeProposal\"C\n\rModuleVersion\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07version\x18\x02 \x01(\x04R\x07version:\x04\xe8\xa0\x1f\x01\x42\xc6\x01\n\x1a\x63om.cosmos.upgrade.v1beta1B\x0cUpgradeProtoP\x01Z\x1c\x63osmossdk.io/x/upgrade/types\xa2\x02\x03\x43UX\xaa\x02\x16\x43osmos.Upgrade.V1beta1\xca\x02\x16\x43osmos\\Upgrade\\V1beta1\xe2\x02\"Cosmos\\Upgrade\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Upgrade::V1beta1\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.upgrade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.upgrade.v1beta1B\014UpgradeProtoP\001Z\034cosmossdk.io/x/upgrade/types\242\002\003CUX\252\002\026Cosmos.Upgrade.V1beta1\312\002\026Cosmos\\Upgrade\\V1beta1\342\002\"Cosmos\\Upgrade\\V1beta1\\GPBMetadata\352\002\030Cosmos::Upgrade::V1beta1\310\341\036\000'
  _globals['_PLAN'].fields_by_name['time']._loaded_options = None
  _globals['_PLAN'].fields_by_name['time']._serialized_options = b'\030\001\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PLAN'].fields_by_name['upgraded_client_state']._loaded_options = None
  _globals['_PLAN'].fields_by_name['upgraded_client_state']._serialized_options = b'\030\001'
  _globals['_PLAN']._loaded_options = None
  _globals['_PLAN']._serialized_options = b'\350\240\037\001\212\347\260*\017cosmos-sdk/Plan'
  _globals['_SOFTWAREUPGRADEPROPOSAL'].fields_by_name['plan']._loaded_options = None
  _globals['_SOFTWAREUPGRADEPROPOSAL'].fields_by_name['plan']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_SOFTWAREUPGRADEPROPOSAL']._loaded_options = None
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_options = b'\030\001\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\"cosmos-sdk/SoftwareUpgradeProposal'
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._loaded_options = None
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_options = b'\030\001\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*(cosmos-sdk/CancelSoftwareUpgradeProposal'
  _globals['_MODULEVERSION']._loaded_options = None
  _globals['_MODULEVERSION']._serialized_options = b'\350\240\037\001'
  _globals['_PLAN']._serialized_start=193
  _globals['_PLAN']._serialized_end=432
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_start=435
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_end=654
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_start=657
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_end=827
  _globals['_MODULEVERSION']._serialized_start=829
  _globals['_MODULEVERSION']._serialized_end=896
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/multisig/v1beta1/multisig.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/crypto/multisig/v1beta1/multisig.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-cosmos/crypto/multisig/v1beta1/multisig.proto\x12\x1e\x63osmos.crypto.multisig.v1beta1\x1a\x14gogoproto/gogo.proto\"6\n\x0eMultiSignature\x12\x1e\n\nsignatures\x18\x01 \x03(\x0cR\nsignatures:\x04\xd0\xa1\x1f\x01\"Y\n\x0f\x43ompactBitArray\x12*\n\x11\x65xtra_bits_stored\x18\x01 \x01(\rR\x0f\x65xtraBitsStored\x12\x14\n\x05\x65lems\x18\x02 \x01(\x0cR\x05\x65lems:\x04\x98\xa0\x1f\x00\x42\xf9\x01\n\"com.cosmos.crypto.multisig.v1beta1B\rMultisigProtoP\x01Z)github.com/cosmos/cosmos-sdk/crypto/types\xa2\x02\x03\x43\x43M\xaa\x02\x1e\x43osmos.Crypto.Multisig.V1beta1\xca\x02\x1e\x43osmos\\Crypto\\Multisig\\V1beta1\xe2\x02*Cosmos\\Crypto\\Multisig\\V1beta1\\GPBMetadata\xea\x02!Cosmos::Crypto::Multisig::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.v1beta1.multisig_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.cosmos.crypto.multisig.v1beta1B\rMultisigProtoP\001Z)github.com/cosmos/cosmos-sdk/crypto/types\242\002\003CCM\252\002\036Cosmos.Crypto.Multisig.V1beta1\312\002\036Cosmos\\Crypto\\Multisig\\V1beta1\342\002*Cosmos\\Crypto\\Multisig\\V1beta1\\GPBMetadata\352\002!Cosmos::Crypto::Multisig::V1beta1'
  _globals['_MULTISIGNATURE']._loaded_options = None
  _globals['_MULTISIGNATURE']._serialized_options = b'\320\241\037\001'
  _globals['_COMPACTBITARRAY']._loaded_options = None
  _globals['_COMPACTBITARRAY']._serialized_options = b'\230\240\037\000'
  _globals['_MULTISIGNATURE']._serialized_start=103
  _globals['_MULTISIGNATURE']._serialized_end=157
  _globals['_COMPACTBITARRAY']._serialized_start=159
  _globals['_COMPACTBITARRAY']._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/nft/module/v1/module.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/nft/module/v1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/nft/module/v1/module.proto\x12\x14\x63osmos.nft.module.v1\x1a cosmos/app/v1alpha1/module.proto\"$\n\x06Module:\x1a\xba\xc0\x96\xda\x01\x14\n\x12\x63osmossdk.io/x/nftB\x9a\x01\n\x18\x63om.cosmos.nft.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43NM\xaa\x02\x14\x43osmos.Nft.Module.V1\xca\x02\x14\x43osmos\\Nft\\Module\\V1\xe2\x02 Cosmos\\Nft\\Module\\V1\\GPBMetadata\xea\x02\x17\x43osmos::Nft::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.nft.module.v1B\013ModuleProtoP\001\242\002\003CNM\252\002\024Cosmos.Nft.Module.V1\312\002\024Cosmos\\Nft\\Module\\V1\342\002 Cosmos\\Nft\\Module\\V1\\GPBMetadata\352\002\027Cosmos::Nft::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\024\n\022cosmossdk.io/x/nft'
  _globals['_MODULE']._serialized_start=93
  _globals['_MODULE']._serialized_end=129
# @@protoc_insertion_point(module_scope)
